# k-vision
[![Build Status](https://travis-ci.com/krinj/k-vision.svg?branch=master)](https://travis-ci.com/krinj/k-vision) [![codecov](https://codecov.io/gh/krinj/k-vision/branch/master/graph/badge.svg)](https://codecov.io/gh/krinj/k-vision) ![Version](https://img.shields.io/badge/version-0.0.2-333333.svg)

Work in progress.